.. _numdisplay:

**************************
NumDisplay Class Interface
**************************

This class provides the primary functionality for displaying numpy arrays in DS9 using the IIS protocol.

.. currentmodule:: stsci.numdisplay

.. automodule:: stsci.numdisplay

.. autoclass:: NumDisplay
   :members:
   :undoc-members:

